#!/usr/bin/python

from ws2udp.ws2udp import run

import asyncio
import argparse
import logging

def main():
    parser = argparse.ArgumentParser(
        description="WebSocket to UDP proxy"
        )
    parser.add_argument("--udp-addr", default="localhost", help="Address of the UDP receiver for broadcasting messages (default=localhost)")
    parser.add_argument("--udp-port", default="57142", help="Port of the UDP receiver (default=57142)")
    parser.add_argument("--addr", default="0.0.0.0", help="WebSocket address to listen (default=0.0.0.0)")
    parser.add_argument("--port", default=8765, help="WebSocket port to listen (default=8765)")
    parser.add_argument("--quiet", action='store_true', help="No verbose output")
    
    args = parser.parse_args()

    if args.quiet:
        logging.basicConfig(level=logging.WARNING, format="%(message)s")
    else:
        logging.basicConfig(level=logging.INFO, format="%(message)s")

    udp_addr = (args.udp_addr, int(args.udp_port))
    logging.info(f"Forwarding WebSocket messages received on {args.addr}:{args.port}")
    logging.info(f"Broadcasting UDP messages received on {args.udp_addr}:{args.udp_port}")

    try:
        asyncio.run(run(udp_addr, args.addr, args.port))
        asyncio.get_event_loop().run_forever()
    except KeyboardInterrupt:
        logging.info("Quitting...")



from setuptools import setup, find_namespace_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(name='ws2udp',
      version='0.1.6',
      author='Bruno Gola',
      author_email='me@bgo.la',
      description='A WebSocket to UDP proxy',
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/bgola/ws2udp",
      packages=find_namespace_packages(include=['ws2udp']),
	  classifiers=[
          "Programming Language :: Python :: 3",
          "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
          "Operating System :: OS Independent",
		  "Framework :: AsyncIO",
      ],
	  install_requires=['websockets'],
      keywords='websockets udp osc opensoundcontrol',
      python_requires='>=3.7',
      entry_points={
          'console_scripts': [
              'ws2udp = ws2udp.__main__:main'
          ]
      },
      )
